// Copyright (c) 2023, the Dart project authors.  Please see the AUTHORS file
// for details. All rights reserved. Use of this source code is governed by a
// BSD-style license that can be found in the LICENSE file.

import 'dart:js_interop';

import 'webgl1.dart';

@JS('EXT_sRGB')
@staticInterop
class EXT_sRGB {
  external static GLenum get SRGB_EXT;
  external static GLenum get SRGB_ALPHA_EXT;
  external static GLenum get SRGB8_ALPHA8_EXT;
  external static GLenum get FRAMEBUFFER_ATTACHMENT_COLOR_ENCODING_EXT;
}
